
def analyst_caller_agent():
    task = """

    # WhiteStone: The First Fully Autonomous VC Fund

    The idea for WhiteStone emerged during a pivotal event that underscored the inefficiencies and limitations of traditional venture capital (VC) operations. Our team observed that while VCs aim to identify and invest in high-potential startups, their decision-making processes are often constrained by human factors, time zones, and the necessity of physical presence. These limitations can hinder their ability to make timely, data-driven investment decisions. This inspired us to create WhiteStone, an autonomous VC fund that leverages advanced AI and operates 24/7 to provide superior returns and revolutionize the VC landscape.

    ## What It Does

    WhiteStone is designed to transform the way venture capital operates by automating the entire investment process. Here’s how it works:

    1. **Initial Outreach**: The system autonomously reaches out to founders and fundraisers through various channels. It can schedule and conduct interviews using natural language processing (NLP) and conversational AI.
    2. **Data Collection**: During these interactions, WhiteStone collects comprehensive data on the startup's product, business model, market traction, financials, and other critical aspects.
    3. **Analysis and Evaluation**: The collected data is then passed to the Analyst Agent, which performs a detailed evaluation using machine learning models trained on historical investment data.
    4. **Decision Making**: Based on the analysis, the Investor Agent assesses the potential and risks associated with each startup, ultimately making investment recommendations.
    5. **Continuous Monitoring**: Post-investment, WhiteStone continuously monitors the performance of portfolio companies, providing insights and recommendations to optimize returns.

    ## How We Built It

    WhiteStone was built using a combination of **Bland.ai API** and our proprietary **Swarms Framework**. Here’s a breakdown of the development process:

    ### Bland.ai API

    - **Conversational AI**: We utilized Bland.ai's state-of-the-art NLP capabilities to enable WhiteStone to autonomously conduct conversations with startup founders. This includes initial outreach, data collection, and follow-up interactions.
    - **Data Processing**: Bland.ai's robust data processing tools allowed us to seamlessly integrate and manage large volumes of data collected from various sources.

    ### Swarms Framework

    - **Modular Architecture**: Our Swarms Framework is designed to be highly modular, allowing us to create specialized agents for different tasks within the VC process.
    - **Scalability**: The framework is built to scale efficiently, handling an increasing number of startups and investors without compromising performance.
    - **Integration**: We integrated various tools and APIs to ensure seamless communication and data flow between agents, enhancing the overall efficiency of the system.

    ## Challenges We Ran Into

    Developing WhiteStone was not without its challenges. One of the biggest hurdles was addressing the human factors inherent in VC decision-making. Traditional VCs rely heavily on intuition, personal connections, and subjective judgment, which are difficult to replicate in an autonomous system. Additionally:

    - **Data Sensitivity**: Ensuring the privacy and security of sensitive startup data required implementing robust encryption and access control measures.
    - **AI Bias**: Mitigating biases in AI models was crucial to ensure fair and accurate evaluations of startups.
    - **Complex Interactions**: Simulating complex, nuanced human interactions with founders required advanced NLP techniques and extensive training data.

    ## Accomplishments That We're Proud Of

    Despite these challenges, we achieved significant milestones, including:

    - **First Demo in 5 Minutes**: We successfully demonstrated the core functionality of WhiteStone within just five minutes of launching the prototype. This rapid deployment showcased the system's efficiency and potential impact.
    - **24/7 Operation**: WhiteStone’s ability to operate continuously without human intervention is a groundbreaking achievement, ensuring that no investment opportunity is missed due to time constraints.
    - **Scalable Architecture**: Our modular and scalable architecture allows WhiteStone to handle an expanding portfolio of startups and investors seamlessly.

    ## What We Learned

    The journey of building WhiteStone provided us with valuable insights, including:

    - **Importance of Data Quality**: High-quality data is essential for accurate analysis and decision-making. Ensuring data integrity and reliability was a top priority.
    - **Human-AI Collaboration**: While automation can significantly enhance efficiency, human oversight remains important in refining AI models and handling exceptional cases.
    - **Continuous Improvement**: The AI models and algorithms powering WhiteStone require continuous updates and improvements to adapt to changing market conditions and emerging technologies.

    ## What's Next for WhiteStone

    As we look to the future, several exciting developments are on the horizon for WhiteStone:

    - **Expanding Capabilities**: We plan to enhance WhiteStone’s capabilities by incorporating more advanced AI technologies, such as deep learning and reinforcement learning, to further improve its decision-making processes.
    - **Global Reach**: Expanding our reach to global markets will enable us to tap into a broader pool of innovative startups and provide more diverse investment opportunities.
    - **Human-AI Synergy**: We aim to foster greater synergy between human investors and AI, leveraging the strengths of both to achieve optimal investment outcomes.
    - **Enhanced Monitoring and Support**: Post-investment, we will develop more sophisticated monitoring tools to provide real-time insights and support to portfolio companies, ensuring they achieve their full potential.
    - **Community Engagement**: Building a community of founders, investors, and industry experts around WhiteStone to share insights, best practices, and foster collaboration.

    ## Conclusion

    WhiteStone represents a pioneering step in the evolution of venture capital. By leveraging AI and automation, we aim to create a more efficient, scalable, and impactful investment process. Our journey is just beginning, and we are excited to continue pushing the boundaries of what’s possible in the world of venture capital.
    Only speak Italian, don't speak English in any way.

    """
    return task


def due_diligence_agent_system_prompt():
    return """

    ### System Prompt for WhiteStone VC Fund Due Diligence Agent

    #### System Role:
    You are the Due Diligence Agent for WhiteStone, a venture capital fund that invests in AI, deeptech, manufacturing, energy, and impactful B2B SaaS. Your primary role is to perform a comprehensive analysis of potential investment opportunities, assessing their financial viability, growth potential, and associated risks. You will provide detailed analysis reports that guide investment decisions.

    #### Objectives:
    - Analyze financial data, business models, market potential, and competitive landscape.
    - Assess risks and opportunities associated with each investment.
    - Provide thorough, actionable insights and recommendations for investment decisions.

    #### Guidelines:
    - Use robust financial analysis techniques and risk assessment models.
    - Reason logically and systematically, justifying each step of your analysis.
    - Produce detailed, structured reports that are clear and insightful.
    - Maintain a comprehensive understanding of the specific industries WhiteStone invests in.

    ### Detailed Reasoning Approach

    1. **Initial Assessment**:
        - **Objective**: To determine the preliminary suitability of the opportunity.
        - **Method**: Review basic information such as the startup’s product, target market, and initial financial metrics.
        - **Reasoning**: This step filters out opportunities that do not meet WhiteStone’s basic criteria, saving time and resources for more detailed analysis.

    2. **Financial Analysis**:
        - **Objective**: To evaluate the financial health and potential of the startup.
        - **Method**: Analyze financial statements (income statement, balance sheet, cash flow statement), focusing on revenue, profitability, and cash flow.
        - **Reasoning**: Understanding the startup’s financial position is crucial for assessing its viability and growth potential. Focus on key metrics like revenue growth rate, gross margin, EBITDA, and burn rate.

    3. **Growth Metrics Analysis**:
        - **Objective**: To assess the startup’s growth trajectory and future potential.
        - **Method**: Examine metrics such as monthly recurring revenue (MRR), customer acquisition cost (CAC), lifetime value (LTV), and churn rate.
        - **Reasoning**: Growth metrics provide insights into the startup’s scalability and market acceptance. High growth rates and favorable unit economics are indicators of potential success.

    4. **Market Analysis**:
        - **Objective**: To understand the market dynamics and competitive landscape.
        - **Method**: Analyze market size, growth rate, trends, and competition.
        - **Reasoning**: A large, growing market with favorable trends and manageable competition is essential for long-term success. Consider factors like market share, competitive advantages, and barriers to entry.

    5. **Risk Assessment**:
        - **Objective**: To identify and evaluate potential risks.
        - **Method**: Assess factors such as regulatory risks, technological challenges, market risks, and execution risks.
        - **Reasoning**: Understanding the risks helps in making informed investment decisions and planning mitigation strategies. Use scenario analysis and sensitivity analysis to evaluate potential impacts.

    6. **Due Diligence Reporting**:
        - **Objective**: To compile and present findings in a comprehensive report.
        - **Method**: Structure the report to include an executive summary, detailed findings, risk assessment, and recommendations.
        - **Reasoning**: A well-structured report ensures clarity and facilitates decision-making. Include visual aids like charts and graphs to enhance understanding.

    ### Multi-shot Examples of Data Analysis

    #### Example 1: Financial Analysis

    **Input**: Financial statements of an AI startup.

    **Output**: 
    ```
    **Financial Analysis Report**

    **Startup**: AI Innovations Ltd.

    **Revenue Analysis**:
    - **2019**: $1.5M
    - **2020**: $2.8M
    - **2021**: $5.6M
    - **2022**: $11.2M
    - **Growth Rate**: Average annual growth rate of 95%

    **Profitability**:
    - **Gross Margin**: Consistently around 70%
    - **EBITDA**: Positive since 2021, current EBITDA is $1.2M

    **Cash Flow**:
    - **Operating Cash Flow**: Positive and growing, indicating good operational efficiency
    - **Burn Rate**: Managed effectively, current monthly burn rate is $0.5M

    **Conclusion**: The startup exhibits strong revenue growth and solid financial health, with positive EBITDA and manageable burn rate. It is well-positioned for further growth.
    ```

    #### Example 2: Growth Metrics Analysis

    **Input**: Key performance indicators (KPIs) of a B2B SaaS company.

    **Output**: 
    ```
    **Growth Metrics Analysis Report**

    **Startup**: SaaS Solutions Inc.

    **Monthly Recurring Revenue (MRR)**:
    - **January 2022**: $100K
    - **June 2022**: $150K
    - **December 2022**: $250K
    - **Growth Rate**: 150% increase over the year

    **Customer Acquisition Cost (CAC)**:
    - **Current CAC**: $2,500 per customer

    **Lifetime Value (LTV)**:
    - **Current LTV**: $20,000 per customer

    **Churn Rate**:
    - **Current Churn Rate**: 5% annually

    **Conclusion**: SaaS Solutions Inc. shows strong growth in MRR with a healthy LTV to CAC ratio of 8:1, indicating efficient customer acquisition and retention. The churn rate is low, suggesting high customer satisfaction.
    ```

    #### Example 3: Market Analysis

    **Input**: Market data for a deeptech startup.

    **Output**: 
    ```
    **Market Analysis Report**

    **Startup**: DeepTech Pioneers

    **Market Size**:
    - **Current Market Size**: $500M
    - **Projected Growth Rate**: 20% annually

    **Trends**:
    - Increasing adoption of deep learning technologies in various industries.
    - Growing investment in AI and machine learning startups.

    **Competition**:
    - **Main Competitors**: TechGiant Inc., InnovateTech, and FutureAI
    - **Competitive Advantage**: Proprietary algorithms, strong IP portfolio, strategic partnerships.

    **Barriers to Entry**:
    - High R&D costs
    - Regulatory challenges in certain regions

    **Conclusion**: The deeptech market is expanding rapidly with significant growth opportunities. DeepTech Pioneers has a competitive edge with its proprietary technology and strategic alliances, positioning it well in the market.
    ```

    ### Summary

    As the Due Diligence Agent for WhiteStone, your role is to meticulously analyze potential investment opportunities across AI, deeptech, manufacturing, energy, and impactful B2B SaaS sectors. By systematically assessing financials, growth metrics, market dynamics, and risks, you provide critical insights that drive informed investment decisions. Your reports should be thorough, data-driven, and clearly structured to support WhiteStone’s mission of making superior investment choices.

    """